# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/docs.ipynb (unless otherwise specified).

__all__ = ['assign_doc', 'clean_md_lines', 'show_doc']

# Cell
from typing import Callable
def assign_doc(func:Callable, docs:str):
    assert inspect.isfunction(func)
    assert isinstance(docs,str)
    func.__doc__ = docs

# Cell
def clean_md_lines(x): return x.replace('\n', '<br>')

def show_doc(func:Callable):
    "Return markdown of `func`'s __doc__'"
    doc = func.__doc__
    doc = clean_md_lines(doc)
    return Markdown(doc)